==> image-saas-domain-0.0.904-sources.jar: com/xforceplus/imagesaas/entity/CompareTicketPlaneDetail.java <==
package com.xforceplus.imagesaas.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 数据比对用途的飞机票明细
 * </p>
 *
 * @author ultraman
 * @since 2022-06-30
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class CompareTicketPlaneDetail implements Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 承运人
   */
  private String carrier;

  /**
   * 出发站
   */
  private String planeFrom;

  /**
   * 目的地
   */
  private String planeTo;

  /**
   * 航班号
   */
  private String flight;

  /**
   * 乘机日期
   */
  private String planeDate;

  /**
   * 乘机时间
   */
  private String planeTime;

  /**
   * 座位等级
   */
  private String seatClass;

  /**
   * 客票级别/客票类别
   */
  private String fareBasis;

  /**
   * 客票生效日期
   */
  private String notValidBefore;

  /**
   * 客票失效日期
   */
  private String notValidAfter;

  /**
   * 免费行李
   */
  private String allow;

  /**
   * 单证主ID
   */
  private Long ticketId;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 租户名称
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 详情摘要
   */
  private String summary;

  /**
   * 扩展信息
   */
  private String extra;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("carrier", carrier);
      map.put("plane_from", planeFrom);
      map.put("plane_to", planeTo);
      map.put("flight", flight);
      map.put("plane_date", planeDate);
      map.put("plane_time", planeTime);
      map.put("seat_class", seatClass);
      map.put("fare_basis", fareBasis);
      map.put("not_valid_before", notValidBefore);
      map.put("not_valid_after", notValidAfter);
      map.put("allow", allow);
      map.put("ticket_id", ticketId);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("tenant_code", tenantCode);
      map.put("summary", summary);
      map.put("extra", extra);
      return map;
  }

  public static CompareTicketPlaneDetail fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    CompareTicketPlaneDetail entity = new CompareTicketPlaneDetail();
    if(map.containsKey("carrier")) {
      Object obj = map.get("carrier");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCarrier((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_from")) {
      Object obj = map.get("plane_from");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPlaneFrom((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_to")) {
      Object obj = map.get("plane_to");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPlaneTo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("flight")) {
      Object obj = map.get("flight");
      if(obj != null) {
        if(obj instanceof String){
          entity.setFlight((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_date")) {
      Object obj = map.get("plane_date");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPlaneDate((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_time")) {
      Object obj = map.get("plane_time");
      if(obj != null) {
        if(obj instanceof String){
          entity.setPlaneTime((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("seat_class")) {
      Object obj = map.get("seat_class");
      if(obj != null) {
        if(obj instanceof String){
          entity.setSeatClass((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("fare_basis")) {
      Object obj = map.get("fare_basis");
      if(obj != null) {
        if(obj instanceof String){
          entity.setFareBasis((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("not_valid_before")) {
      Object obj = map.get("not_valid_before");
      if(obj != null) {
        if(obj instanceof String){
          entity.setNotValidBefore((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("not_valid_after")) {
      Object obj = map.get("not_valid_after");
      if(obj != null) {
        if(obj instanceof String){
          entity.setNotValidAfter((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("allow")) {
      Object obj = map.get("allow");
      if(obj != null) {
        if(obj instanceof String){
          entity.setAllow((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ticket_id")) {
      Object obj = map.get("ticket_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTicketId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTicketId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTicketId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime){
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer){
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("summary")) {
      Object obj = map.get("summary");
      if(obj != null) {
        if(obj instanceof String){
          entity.setSummary((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("extra")) {
      Object obj = map.get("extra");
      if(obj != null) {
        if(obj instanceof String){
          entity.setExtra((String)obj);
        }
      } else{
      }
    }
    return entity;
  }
}

==> image-saas-domain-0.1.266-sources.jar: com/xforceplus/imagesaas/entity/CompareTicketPlaneDetail.java <==
package com.xforceplus.imagesaas.entity;

import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import com.xforceplus.ultraman.bocp.gen.util.BocpGenUtils;
import com.xforceplus.ultraman.bocp.gen.obj.MetadataConvertable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 数据比对用途的飞机票明细
 * </p>
 *
 * @author ultraman
 * @since 2023-06-21
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class CompareTicketPlaneDetail implements MetadataConvertable, Serializable {

  private static final long serialVersionUID=1L;

  /**
   * 承运人
   */
  private String carrier;

  /**
   * 出发站
   */
  private String planeFrom;

  /**
   * 目的地
   */
  private String planeTo;

  /**
   * 航班号
   */
  private String flight;

  /**
   * 乘机日期
   */
  private String planeDate;

  /**
   * 乘机时间
   */
  private String planeTime;

  /**
   * 座位等级
   */
  private String seatClass;

  /**
   * 客票级别/客票类别
   */
  private String fareBasis;

  /**
   * 客票生效日期
   */
  private String notValidBefore;

  /**
   * 客票失效日期
   */
  private String notValidAfter;

  /**
   * 免费行李
   */
  private String allow;

  /**
   * 单证主ID
   */
  private Long ticketId;

  /**
   * id
   */
  private Long id;

  /**
   * 租户id
   */
  @TableField(fill = FieldFill.INSERT)
  private Long tenantId;

  /**
   * 创建时间
   */
  @TableField(fill = FieldFill.INSERT)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime createTime;

  /**
   * 修改时间
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
  private LocalDateTime updateTime;

  /**
   * 创建人
   */
  @TableField(fill = FieldFill.INSERT)
  private Long createUserId;

  /**
   * 修改人
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private Long updateUserId;

  /**
   * 创建人名字
   */
  @TableField(fill = FieldFill.INSERT)
  private String createUserName;

  /**
   * 修改人名字
   */
  @TableField(fill = FieldFill.INSERT_UPDATE)
  private String updateUserName;

  /**
   * 删除标记
   */
  @TableField(fill = FieldFill.INSERT)
  private String deleteFlag;

  /**
   * 租户名称
   */
  @TableField(fill = FieldFill.INSERT)
  private String tenantCode;

  /**
   * 详情摘要
   */
  private String summary;

  /**
   * 扩展信息
   */
  private String extra;




  public Map toOQSMap(){
      Map map = new HashMap();
      map.put("carrier", carrier);
      map.put("plane_from", planeFrom);
      map.put("plane_to", planeTo);
      map.put("flight", flight);
      map.put("plane_date", planeDate);
      map.put("plane_time", planeTime);
      map.put("seat_class", seatClass);
      map.put("fare_basis", fareBasis);
      map.put("not_valid_before", notValidBefore);
      map.put("not_valid_after", notValidAfter);
      map.put("allow", allow);
      map.put("ticket_id", ticketId);
      map.put("id", id);
      map.put("tenant_id", tenantId);
      map.put("create_time", BocpGenUtils.toTimestamp(createTime));
      map.put("update_time", BocpGenUtils.toTimestamp(updateTime));
      map.put("create_user_id", createUserId);
      map.put("update_user_id", updateUserId);
      map.put("create_user_name", createUserName);
      map.put("update_user_name", updateUserName);
      map.put("delete_flag", deleteFlag);
      map.put("tenant_code", tenantCode);
      map.put("summary", summary);
      map.put("extra", extra);

      return map;
  }

  public static CompareTicketPlaneDetail fromOQSMap(Map map){
    if(map == null || map.isEmpty()) {
      return null;
    }
    CompareTicketPlaneDetail entity = new CompareTicketPlaneDetail();
    if(map.containsKey("carrier")) {
      Object obj = map.get("carrier");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setCarrier((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_from")) {
      Object obj = map.get("plane_from");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setPlaneFrom((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_to")) {
      Object obj = map.get("plane_to");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setPlaneTo((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("flight")) {
      Object obj = map.get("flight");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setFlight((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_date")) {
      Object obj = map.get("plane_date");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setPlaneDate((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("plane_time")) {
      Object obj = map.get("plane_time");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setPlaneTime((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("seat_class")) {
      Object obj = map.get("seat_class");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setSeatClass((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("fare_basis")) {
      Object obj = map.get("fare_basis");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setFareBasis((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("not_valid_before")) {
      Object obj = map.get("not_valid_before");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setNotValidBefore((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("not_valid_after")) {
      Object obj = map.get("not_valid_after");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setNotValidAfter((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("allow")) {
      Object obj = map.get("allow");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setAllow((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("ticket_id")) {
      Object obj = map.get("ticket_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTicketId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setTicketId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setTicketId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setTenantId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setTenantId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          entity.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else{
        entity.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setCreateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          entity.setUpdateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          entity.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          entity.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else{
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setCreateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setUpdateUserName((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setDeleteFlag((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setTenantCode((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("summary")) {
      Object obj = map.get("summary");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setSummary((String)obj);
        }
      } else{
      }
    }
    if(map.containsKey("extra")) {
      Object obj = map.get("extra");
      if(obj != null) {
        if(obj instanceof String && !"$NULL$".equals((String)obj)){
          entity.setExtra((String)obj);
        }
      } else{
      }
    }

    return entity;
  }


  protected void setByOQSMap(Map map) {
    if(map.containsKey("carrier")) {
      Object obj = map.get("carrier");
      if(obj != null) {
        if(obj instanceof String) {
          this.setCarrier((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("plane_from")) {
      Object obj = map.get("plane_from");
      if(obj != null) {
        if(obj instanceof String) {
          this.setPlaneFrom((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("plane_to")) {
      Object obj = map.get("plane_to");
      if(obj != null) {
        if(obj instanceof String) {
          this.setPlaneTo((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("flight")) {
      Object obj = map.get("flight");
      if(obj != null) {
        if(obj instanceof String) {
          this.setFlight((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("plane_date")) {
      Object obj = map.get("plane_date");
      if(obj != null) {
        if(obj instanceof String) {
          this.setPlaneDate((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("plane_time")) {
      Object obj = map.get("plane_time");
      if(obj != null) {
        if(obj instanceof String) {
          this.setPlaneTime((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("seat_class")) {
      Object obj = map.get("seat_class");
      if(obj != null) {
        if(obj instanceof String) {
          this.setSeatClass((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("fare_basis")) {
      Object obj = map.get("fare_basis");
      if(obj != null) {
        if(obj instanceof String) {
          this.setFareBasis((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("not_valid_before")) {
      Object obj = map.get("not_valid_before");
      if(obj != null) {
        if(obj instanceof String) {
          this.setNotValidBefore((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("not_valid_after")) {
      Object obj = map.get("not_valid_after");
      if(obj != null) {
        if(obj instanceof String) {
          this.setNotValidAfter((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("allow")) {
      Object obj = map.get("allow");
      if(obj != null) {
        if(obj instanceof String) {
          this.setAllow((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("ticket_id")) {
      Object obj = map.get("ticket_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setTicketId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setTicketId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setTicketId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("id")) {
      Object obj = map.get("id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("tenant_id")) {
      Object obj = map.get("tenant_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setTenantId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setTenantId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setTenantId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("create_time")) {
      Object obj = map.get("create_time");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setCreateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setCreateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setCreateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setCreateTime(null);
      }
    }
    if(map.containsKey("update_time")) {
      Object obj = map.get("update_time");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setUpdateTime(BocpGenUtils.toLocalDateTime((Long)obj));
        } else if(obj instanceof LocalDateTime) {
          this.setUpdateTime((LocalDateTime)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setUpdateTime(BocpGenUtils.toLocalDateTime(Long.parseLong((String)obj)));
        }
      } else {
        this.setUpdateTime(null);
      }
    }
    if(map.containsKey("create_user_id")) {
      Object obj = map.get("create_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setCreateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setCreateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setCreateUserId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("update_user_id")) {
      Object obj = map.get("update_user_id");
      if(obj != null) {
        if(obj instanceof Long) {
          this.setUpdateUserId((Long)obj);
        } else if(obj instanceof String && !"$NULL$".equals((String)obj)) {
          this.setUpdateUserId(Long.parseLong((String)obj));
        } else if(obj instanceof Integer) {
          this.setUpdateUserId(Long.parseLong(obj.toString()));
        }
      } else {
      }
    }
    if(map.containsKey("create_user_name")) {
      Object obj = map.get("create_user_name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setCreateUserName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("update_user_name")) {
      Object obj = map.get("update_user_name");
      if(obj != null) {
        if(obj instanceof String) {
          this.setUpdateUserName((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("delete_flag")) {
      Object obj = map.get("delete_flag");
      if(obj != null) {
        if(obj instanceof String) {
          this.setDeleteFlag((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("tenant_code")) {
      Object obj = map.get("tenant_code");
      if(obj != null) {
        if(obj instanceof String) {
          this.setTenantCode((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("summary")) {
      Object obj = map.get("summary");
      if(obj != null) {
        if(obj instanceof String) {
          this.setSummary((String)obj);
        }
      } else {
      }
    }
    if(map.containsKey("extra")) {
      Object obj = map.get("extra");
      if(obj != null) {
        if(obj instanceof String) {
          this.setExtra((String)obj);
        }
      } else {
      }
    }
  }
}
